"""Workflow for students.
"""
import grok
from datetime import datetime
from zope.component import getUtility
from hurry.workflow.workflow import Transition, WorkflowState, NullCondition
from hurry.workflow.interfaces import IWorkflowState, IWorkflowTransitionEvent
from waeup.kofa.interfaces import (
    IObjectHistory, IKofaWorkflowInfo, IKofaUtils,
    CREATED, ADMITTED, CLEARANCE, REQUESTED, CLEARED, PAID, RETURNING,
    REGISTERED, VALIDATED, GRADUATED, TRANSCRIPT)
from waeup.kofa.interfaces import MessageFactory as _
from waeup.kofa.workflow import KofaWorkflow, KofaWorkflowInfo
from waeup.kofa.students.interfaces import IStudent, IStudentsUtils
from waeup.kofa.students.workflow import RegistrationWorkflowInfo


REGISTRATION_TRANSITIONS = (
    Transition(
        transition_id = 'create',
        title = _('Create customer'),
        source = None,
        condition = NullCondition,
        msg = _('Record created'),
        destination = CREATED),

    Transition(
        transition_id = 'admit',
        title = _('Approve contract'),
        msg = _('Contract approved'),
        source = CREATED,
        destination = ADMITTED),

    Transition(
        transition_id = 'reset1',
        title = _('Reset customer to initial state'),
        msg = _('Reset to initial state'),
        source = ADMITTED,
        destination = CREATED),

    Transition(
        transition_id = 'pay_meter_fee',
        title = _('Pay meter fee'),
        msg = _('Meter fee paid'),
        source = ADMITTED,
        destination = PAID),

    Transition(
        transition_id = 'approve_meter_fee_payment',
        title = _('Approve meter fee payment'),
        msg = _('Meter fee payment approved'),
        source = ADMITTED,
        destination = PAID),

    Transition(
        transition_id = 'reset2',
        title = _("Reset customer to state 'contract approved'"),
        msg = _("Reset to state 'contract approved'"),
        source = PAID,
        destination = ADMITTED),
    )


registration_workflow = KofaWorkflow(REGISTRATION_TRANSITIONS)

class CustomRegistrationWorkflowInfo(RegistrationWorkflowInfo):
    """Adapter to adapt Student objects to workflow info objects.
    """

    def __init__(self, context):
        self.context = context
        self.wf = registration_workflow
